==> floppy-5.5-i486-1.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf mcd )
( cd usr/bin ; ln -sf mtools mcd )
( cd usr/bin ; rm -rf mpartition )
( cd usr/bin ; ln -sf mtools mpartition )
( cd usr/bin ; rm -rf mattrib )
( cd usr/bin ; ln -sf mtools mattrib )
( cd usr/bin ; rm -rf mlabel )
( cd usr/bin ; ln -sf mtools mlabel )
( cd usr/bin ; rm -rf mbadblocks )
( cd usr/bin ; ln -sf mtools mbadblocks )
( cd usr/bin ; rm -rf mcat )
( cd usr/bin ; ln -sf mtools mcat )
( cd usr/bin ; rm -rf mcopy )
( cd usr/bin ; ln -sf mtools mcopy )
( cd usr/bin ; rm -rf mdu )
( cd usr/bin ; ln -sf mtools mdu )
( cd usr/bin ; rm -rf mshortname )
( cd usr/bin ; ln -sf mtools mshortname )
( cd usr/bin ; rm -rf mformat )
( cd usr/bin ; ln -sf mtools mformat )
( cd usr/bin ; rm -rf mrd )
( cd usr/bin ; ln -sf mtools mrd )
( cd usr/bin ; rm -rf mren )
( cd usr/bin ; ln -sf mtools mren )
( cd usr/bin ; rm -rf mshowfat )
( cd usr/bin ; ln -sf mtools mshowfat )
( cd usr/bin ; rm -rf minfo )
( cd usr/bin ; ln -sf mtools minfo )
( cd usr/bin ; rm -rf mclasserase )
( cd usr/bin ; ln -sf mtools mclasserase )
( cd usr/bin ; rm -rf mtype )
( cd usr/bin ; ln -sf mtools mtype )
( cd usr/bin ; rm -rf mdel )
( cd usr/bin ; ln -sf mtools mdel )
( cd usr/bin ; rm -rf mmd )
( cd usr/bin ; ln -sf mtools mmd )
( cd usr/bin ; rm -rf mtoolstest )
( cd usr/bin ; ln -sf mtools mtoolstest )
( cd usr/bin ; rm -rf mdir )
( cd usr/bin ; ln -sf mtools mdir )
( cd usr/bin ; rm -rf mzip )
( cd usr/bin ; ln -sf mtools mzip )
( cd usr/bin ; rm -rf fdmountd )
( cd usr/bin ; ln -sf fdmount fdmountd )
( cd usr/bin ; rm -rf mmove )
( cd usr/bin ; ln -sf mtools mmove )
( cd usr/bin ; rm -rf fdumount )
( cd usr/bin ; ln -sf fdmount fdumount )
( cd usr/bin ; rm -rf mmount )
( cd usr/bin ; ln -sf mtools mmount )
( cd usr/bin ; rm -rf mdeltree )
( cd usr/bin ; ln -sf mtools mdeltree )
( cd usr/bin ; rm -rf fdlist )
( cd usr/bin ; ln -sf fdmount fdlist )
( cd usr/bin ; rm -rf xdfformat )
( cd usr/bin ; ln -sf xdfcopy xdfformat )
( cd usr/man/man1 ; rm -rf fdmountd.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdmountd.1.gz )
( cd usr/man/man1 ; rm -rf fdumount.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdumount.1.gz )
( cd usr/man/man1 ; rm -rf fdlist.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdlist.1.gz )
( cd usr/man/man1 ; rm -rf xdfformat.1.gz )
( cd usr/man/man1 ; ln -sf xdfcopy.1.gz xdfformat.1.gz )

==> floppy-5.6-i686-2.txz: install/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/mtools.conf.new
( cd usr/bin ; rm -rf fdlist )
( cd usr/bin ; ln -sf fdmount fdlist )
( cd usr/bin ; rm -rf fdmountd )
( cd usr/bin ; ln -sf fdmount fdmountd )
( cd usr/bin ; rm -rf fdumount )
( cd usr/bin ; ln -sf fdmount fdumount )
( cd usr/bin ; rm -rf mattrib )
( cd usr/bin ; ln -sf mtools mattrib )
( cd usr/bin ; rm -rf mbadblocks )
( cd usr/bin ; ln -sf mtools mbadblocks )
( cd usr/bin ; rm -rf mcat )
( cd usr/bin ; ln -sf mtools mcat )
( cd usr/bin ; rm -rf mcd )
( cd usr/bin ; ln -sf mtools mcd )
( cd usr/bin ; rm -rf mcopy )
( cd usr/bin ; ln -sf mtools mcopy )
( cd usr/bin ; rm -rf mdel )
( cd usr/bin ; ln -sf mtools mdel )
( cd usr/bin ; rm -rf mdeltree )
( cd usr/bin ; ln -sf mtools mdeltree )
( cd usr/bin ; rm -rf mdir )
( cd usr/bin ; ln -sf mtools mdir )
( cd usr/bin ; rm -rf mdoctorfat )
( cd usr/bin ; ln -sf mtools mdoctorfat )
( cd usr/bin ; rm -rf mdu )
( cd usr/bin ; ln -sf mtools mdu )
( cd usr/bin ; rm -rf mformat )
( cd usr/bin ; ln -sf mtools mformat )
( cd usr/bin ; rm -rf minfo )
( cd usr/bin ; ln -sf mtools minfo )
( cd usr/bin ; rm -rf mlabel )
( cd usr/bin ; ln -sf mtools mlabel )
( cd usr/bin ; rm -rf mmd )
( cd usr/bin ; ln -sf mtools mmd )
( cd usr/bin ; rm -rf mmount )
( cd usr/bin ; ln -sf mtools mmount )
( cd usr/bin ; rm -rf mmove )
( cd usr/bin ; ln -sf mtools mmove )
( cd usr/bin ; rm -rf mpartition )
( cd usr/bin ; ln -sf mtools mpartition )
( cd usr/bin ; rm -rf mrd )
( cd usr/bin ; ln -sf mtools mrd )
( cd usr/bin ; rm -rf mren )
( cd usr/bin ; ln -sf mtools mren )
( cd usr/bin ; rm -rf mshortname )
( cd usr/bin ; ln -sf mtools mshortname )
( cd usr/bin ; rm -rf mshowfat )
( cd usr/bin ; ln -sf mtools mshowfat )
( cd usr/bin ; rm -rf mtoolstest )
( cd usr/bin ; ln -sf mtools mtoolstest )
( cd usr/bin ; rm -rf mtype )
( cd usr/bin ; ln -sf mtools mtype )
( cd usr/bin ; rm -rf mzip )
( cd usr/bin ; ln -sf mtools mzip )
( cd usr/bin ; rm -rf xdfformat )
( cd usr/bin ; ln -sf xdfcopy xdfformat )
( cd usr/man/man1 ; rm -rf fdlist.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdlist.1.gz )
( cd usr/man/man1 ; rm -rf fdmountd.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdmountd.1.gz )
( cd usr/man/man1 ; rm -rf fdumount.1.gz )
( cd usr/man/man1 ; ln -sf fdmount.1.gz fdumount.1.gz )
( cd usr/man/man1 ; rm -rf xdfformat.1.gz )
( cd usr/man/man1 ; ln -sf xdfcopy.1.gz xdfformat.1.gz )
